@@ -105,11 +105,7 @@ extern int main_debug;
     LL_CONTEXT_OPTIONS = 20,       /* LL_CONTEXT_OPTIONS  */
     LL_CONTEXT_CONFIG = 21,        /* LL_CONTEXT_CONFIG  */
     LL_CONTEXT_TEMPLATE_REF = 22,  /* LL_CONTEXT_TEMPLATE_REF  */
-    LL_CONTEXT_FILTERX = 23,       /* LL_CONTEXT_FILTERX  */
-    LL_CONTEXT_FILTERX_SIMPLE_FUNC = 24, /* LL_CONTEXT_FILTERX_SIMPLE_FUNC  */
-    LL_CONTEXT_FILTERX_ENUM = 25,  /* LL_CONTEXT_FILTERX_ENUM  */
-    LL_CONTEXT_FILTERX_FUNC = 26,  /* LL_CONTEXT_FILTERX_FUNC  */
-    LL_CONTEXT_MAX = 27,           /* LL_CONTEXT_MAX  */
+    LL_CONTEXT_MAX = 23,           /* LL_CONTEXT_MAX  */
     KW_ASSIGN = 9000,              /* KW_ASSIGN  */
     KW_OR = 9010,                  /* KW_OR  */
     KW_AND = 9020,                 /* KW_AND  */
@@ -143,7 +139,6 @@ extern int main_debug;
     KW_IF = 10010,                 /* KW_IF  */
     KW_ELSE = 10011,               /* KW_ELSE  */
     KW_ELIF = 10012,               /* KW_ELIF  */
-    KW_FILTERX = 10013,            /* KW_FILTERX  */
     KW_INTERNAL = 10020,           /* KW_INTERNAL  */
     KW_SYSLOG = 10060,             /* KW_SYSLOG  */
     KW_MARK_FREQ = 10071,          /* KW_MARK_FREQ  */
@@ -241,6 +236,7 @@ extern int main_debug;
     KW_DEFAULT_SEVERITY = 10301,   /* KW_DEFAULT_SEVERITY  */
     KW_SDATA_PREFIX = 10302,       /* KW_SDATA_PREFIX  */
     KW_PORT = 10323,               /* KW_PORT  */
+    KW_HTTP = 10324,               /* KW_HTTP  */
     KW_USE_TIME_RECVD = 10340,     /* KW_USE_TIME_RECVD  */
     KW_FACILITY = 10350,           /* KW_FACILITY  */
     KW_SEVERITY = 10351,           /* KW_SEVERITY  */
@@ -321,11 +317,7 @@ extern int main_debug;
 #define LL_CONTEXT_OPTIONS 20
 #define LL_CONTEXT_CONFIG 21
 #define LL_CONTEXT_TEMPLATE_REF 22
-#define LL_CONTEXT_FILTERX 23
-#define LL_CONTEXT_FILTERX_SIMPLE_FUNC 24
-#define LL_CONTEXT_FILTERX_ENUM 25
-#define LL_CONTEXT_FILTERX_FUNC 26
-#define LL_CONTEXT_MAX 27
+#define LL_CONTEXT_MAX 23
 #define KW_ASSIGN 9000
 #define KW_OR 9010
 #define KW_AND 9020
@@ -359,7 +351,6 @@ extern int main_debug;
 #define KW_IF 10010
 #define KW_ELSE 10011
 #define KW_ELIF 10012
-#define KW_FILTERX 10013
 #define KW_INTERNAL 10020
 #define KW_SYSLOG 10060
 #define KW_MARK_FREQ 10071
@@ -457,6 +448,7 @@ extern int main_debug;
 #define KW_DEFAULT_SEVERITY 10301
 #define KW_SDATA_PREFIX 10302
 #define KW_PORT 10323
+#define KW_HTTP 10324
 #define KW_USE_TIME_RECVD 10340
 #define KW_FACILITY 10350
 #define KW_SEVERITY 10351
