@@ -25,6 +25,6 @@
 
 #include "logproto-server.h"
 
-LogProtoServer *log_proto_auto_server_new(LogTransport *transport, const LogProtoServerOptions *options);
+LogProtoServer *log_proto_auto_server_new(LogTransport *transport, const LogProtoServerOptionsStorage *options);
 
 #endif
